0.4.0

- Add condition to add special types to serialize on json_converter function

0.3.1
-----

- BugFix: { in the response_name breaking the client

0.3.0
-----

- Refactor ResponseFactory using a better repr and str.

0.2.0
-----

- Add next page function

0.1.3
-----

- BugFix: Remove Translation from the exception

0.1.2
-----

- BugFix: Compare with the correct var

0.1.1
-----

- BugFix: Remove django import

0.1.0
-----

- Initial release
